import { ProductSchema } from '@byondrnd/showroom-schemas';
import { Visualizer } from '../Visualizer';
import { Infer } from 'jointz';
/** @ignore */
export interface IEventSystem {
    /** every camera zoom or move */
    camera: IEventsTypes.OnCamera;
    /** once, after the visualizer container is injected */
    containerInjected: IEventsTypes.OnContainerInjected;
    /** once, after the visualizer is loaded */
    visualizerLoaded: IEventsTypes.OnVisualizerLoaded;
    /** when scene rendered */
    rendered: IEventsTypes.OnRendered;
    /** when hotspot mouse hovered */
    hoverHotspot: IEventsTypes.onHoverHotspot;
    /** every time a scene is loaded */
    sceneLoaded: IEventsTypes.OnSceneLoaded;
    /** every time a scene is loading */
    sceneLoading: IEventsTypes.OnSceneLoading;
    /** every time a product has be added to the scene and finished display by the user */
    userChangedProduct: IEventsTypes.OnUserChangedProduct;
    /** every time a product has be added to the scene and finished display */
    productChanged: IEventsTypes.OnProductChanged;
    /** every time a set finished display */
    favoritesSceneDisplayed: IEventsTypes.onFavoritesSceneDisplayed;
    /** every time an hotspot was clicked on the scene */
    applicationHotspotClicked: IEventsTypes.onApplicationHotspotClicked;
    /** every time a product was added to favorite */
    productAddedToFavorites: IEventsTypes.onProductAddedToFavorites;
    /** every time a set was added to favorite */
    sceneAddedToFavorites: IEventsTypes.onSceneAddedToFavorites;
    /** every time a product was removed from favorite */
    productRemovedFromFavorites: IEventsTypes.onProductRemovedFromFavorites;
    /** every time a set was removed from favorite */
    sceneRemovedFromFavorites: IEventsTypes.onSceneRemovedFromFavorites;
    /** every time a product was added to cart */
    productAddedToCart: IEventsTypes.onProductAddedToCart;
    /** every time order sample was clicked on scene */
    orderSample: IEventsTypes.onOrderSample;
    /** every time an async operation starts */
    asyncOperationStarted: IEventsTypes.onAsyncOperationStarted;
    /** every time an async operation ends */
    asyncOperationEnded: IEventsTypes.onAsyncOperationEnded;
    /** every time scene is touched */
    sceneTouched: IEventsTypes.onSceneTouched;
    /** every time scene configuration changed */
    sceneConfigurationLabelChanged: IEventsTypes.OnSceneConfigurationLabelChanged;
    /** download scene summary */
    summaryClicked: IEventsTypes.onSummaryClicked;
    /** opened fullscreen */
    fullscreenClicked: IEventsTypes.onFullscreenClicked;
    /** closed fullscreen */
    closeFullscreenClicked: IEventsTypes.onCloseFullscreenClicked;
    /** opened favorites panel */
    favoritesPanelOpened: IEventsTypes.onFavoritesPanelOpened;
    /** closed favorites panel */
    favoritesPanelClosed: IEventsTypes.onFavoritesPanelClosed;
    /** selected favorite scene */
    favoriteSceneClicked: IEventsTypes.onFavoriteSceneClicked;
    /** opened scenes panel  */
    scenesPanelOpened: IEventsTypes.onScenesPanelOpened;
    /** closed scenes panel */
    scenesPanelClosed: IEventsTypes.onScenesPanelClosed;
    /** clicked applications strip button */
    applicationsStripButtonClicked: IEventsTypes.onApplicationsStripButtonClicked;
    /** applications strip opened  */
    applicationsStripOpened: IEventsTypes.onApplicationsStripOpened;
}
/**@ignore */
export declare type EventSystemEventSignature = keyof IEventSystem;
/**@ignore */
export declare type EventSystemEventTypesSignature = IEventSystem[EventSystemEventSignature];
/**@ignore */
export declare type EventSystemEventDataSignature = Parameters<EventSystemEventTypesSignature>;
declare type TAnalyticsEvent = Partial<{
    [key in keyof IEventSystem]: {
        category: string;
        eventParamsPaths: string[];
    };
}>;
/**
 * property names are assigned to **action**
 *
 * evenParamsPaths are serialized into **label** (and delimited with ':')
 */
export declare const analyticsEvents: TAnalyticsEvent;
declare const configurationFilterValidator: import("jointz/lib/validators/object-validator").default<{
    name: import("jointz/lib/validators/string-validator").default;
    customFieldName: import("jointz/lib/validators/string-validator").default;
    operator: import("jointz/lib/validators/constant-validator").default<["not"]>;
    options: import("jointz/lib/validators/or-validator").default<any>;
}, "name" | "options", false>;
export declare type IConfigurationFilter = Infer<typeof configurationFilterValidator>;
declare const sceneValidator: import("jointz/lib/validators/object-validator").default<{
    experienceId: import("jointz/lib/validators/string-validator").default;
    sceneId: import("jointz/lib/validators/string-validator").default;
    title: import("jointz/lib/validators/string-validator").default;
    subtitle: import("jointz/lib/validators/string-validator").default;
    image: import("jointz/lib/validators/string-validator").default;
    filters: import("jointz/lib/validators/array-validator").default<{
        name?: string;
        customFieldName?: string;
        operator?: "not";
        options?: any;
    } & {
        name: string;
        options: any;
    }>;
}, "image" | "experienceId" | "sceneId", false>;
export declare type IScene = Infer<typeof sceneValidator>;
declare const productShortValidator: import("jointz/lib/validators/object-validator").default<{
    sku: import("jointz/lib/validators/string-validator").default;
    application: import("jointz/lib/validators/string-validator").default;
}, "sku" | "application", false>;
export declare type IProductShort = Infer<typeof productShortValidator>;
export declare const favoriteShortValidator: import("jointz/lib/validators/object-validator").default<{
    product: import("jointz/lib/validators/object-validator").default<{
        sku: import("jointz/lib/validators/string-validator").default;
        application: import("jointz/lib/validators/string-validator").default;
    }, "sku" | "application", false>;
}, "product", false>;
export declare type IFavoriteShort = Infer<typeof favoriteShortValidator>;
declare const facetValidator: import("jointz/lib/validators/object-validator").default<{
    name: import("jointz/lib/validators/string-validator").default;
    options: import("jointz/lib/validators/or-validator").default<any>;
}, "name" | "options", false>;
export declare type IFacet = Infer<typeof facetValidator>;
declare const productValidator: import("jointz/lib/validators/object-validator").default<{
    sku: import("jointz/lib/validators/string-validator").default;
    name: import("jointz/lib/validators/string-validator").default;
    title: import("jointz/lib/validators/string-validator").default;
    description: import("jointz/lib/validators/string-validator").default;
    application: import("jointz/lib/validators/string-validator").default;
    image: import("jointz/lib/validators/string-validator").default;
    price: import("jointz/lib/validators/string-validator").default;
    facets: import("jointz/lib/validators/array-validator").default<{
        name?: string;
        options?: any;
    } & {
        name: string;
        options: any;
    }>;
}, "sku" | "title" | "image" | "application", false>;
export declare type IProduct = Infer<typeof productValidator>;
declare const favoriteValidator: import("jointz/lib/validators/object-validator").default<{
    product: import("jointz/lib/validators/object-validator").default<{
        sku: import("jointz/lib/validators/string-validator").default;
        name: import("jointz/lib/validators/string-validator").default;
        title: import("jointz/lib/validators/string-validator").default;
        description: import("jointz/lib/validators/string-validator").default;
        application: import("jointz/lib/validators/string-validator").default;
        image: import("jointz/lib/validators/string-validator").default;
        price: import("jointz/lib/validators/string-validator").default;
        facets: import("jointz/lib/validators/array-validator").default<{
            name?: string;
            options?: any;
        } & {
            name: string;
            options: any;
        }>;
    }, "sku" | "title" | "image" | "application", false>;
}, "product", false>;
export declare type IFavorite = Infer<typeof favoriteValidator>;
declare const favoriteSceneValidator: import("jointz/lib/validators/object-validator").default<{
    id: import("jointz/lib/validators/string-validator").default;
    image: import("jointz/lib/validators/string-validator").default;
    favorites: import("jointz/lib/validators/array-validator").default<{
        product?: {
            sku?: string;
            name?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: ({
                name?: string;
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            sku: string;
            title: string;
            image: string;
            application: string;
        };
    } & {
        product: {
            sku?: string;
            name?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: ({
                name?: string;
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            sku: string;
            title: string;
            image: string;
            application: string;
        };
    }>;
    scene: import("jointz/lib/validators/object-validator").default<{
        experienceId: import("jointz/lib/validators/string-validator").default;
        sceneId: import("jointz/lib/validators/string-validator").default;
        title: import("jointz/lib/validators/string-validator").default;
        subtitle: import("jointz/lib/validators/string-validator").default;
        image: import("jointz/lib/validators/string-validator").default;
        filters: import("jointz/lib/validators/array-validator").default<{
            name?: string;
            customFieldName?: string;
            operator?: "not";
            options?: any;
        } & {
            name: string;
            options: any;
        }>;
    }, "image" | "experienceId" | "sceneId", false>;
}, "image" | "id" | "favorites" | "scene", false>;
export declare type IFavoriteScene = Infer<typeof favoriteSceneValidator>;
export declare const favoriteSceneListValidator: import("jointz/lib/validators/array-validator").default<{
    id?: string;
    image?: string;
    favorites?: ({
        product?: {
            sku?: string;
            name?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: ({
                name?: string;
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            sku: string;
            title: string;
            image: string;
            application: string;
        };
    } & {
        product: {
            sku?: string;
            name?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: ({
                name?: string;
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            sku: string;
            title: string;
            image: string;
            application: string;
        };
    })[];
    scene?: {
        experienceId?: string;
        sceneId?: string;
        title?: string;
        subtitle?: string;
        image?: string;
        filters?: ({
            name?: string;
            customFieldName?: string;
            operator?: "not";
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        image: string;
        experienceId: string;
        sceneId: string;
    };
} & {
    image: string;
    id: string;
    favorites: ({
        product?: {
            sku?: string;
            name?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: ({
                name?: string;
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            sku: string;
            title: string;
            image: string;
            application: string;
        };
    } & {
        product: {
            sku?: string;
            name?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: ({
                name?: string;
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            sku: string;
            title: string;
            image: string;
            application: string;
        };
    })[];
    scene: {
        experienceId?: string;
        sceneId?: string;
        title?: string;
        subtitle?: string;
        image?: string;
        filters?: ({
            name?: string;
            customFieldName?: string;
            operator?: "not";
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        image: string;
        experienceId: string;
        sceneId: string;
    };
}>;
export declare type IFavoriteSceneList = Infer<typeof favoriteSceneListValidator>;
export declare const favoriteProductListValidator: import("jointz/lib/validators/array-validator").default<{
    product?: {
        sku?: string;
        name?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: ({
            name?: string;
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        sku: string;
        title: string;
        image: string;
        application: string;
    };
} & {
    product: {
        sku?: string;
        name?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: ({
            name?: string;
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        sku: string;
        title: string;
        image: string;
        application: string;
    };
}>;
export declare type IFavoriteProductList = Infer<typeof favoriteProductListValidator>;
export declare const favoriteProductShortListValidator: import("jointz/lib/validators/array-validator").default<{
    product?: {
        sku?: string;
        application?: string;
    } & {
        sku: string;
        application: string;
    };
} & {
    product: {
        sku?: string;
        application?: string;
    } & {
        sku: string;
        application: string;
    };
}>;
export declare type IFavoriteProductShortList = Infer<typeof favoriteProductShortListValidator>;
export interface IApplication {
    application: string;
    title: string;
    image?: string;
    buttons?: IApplicationButtonsConfiguration;
    fields?: IApplicationFieldsConfiguration;
}
export interface ICatalogFieldsMapping {
    title?: string;
    description?: string;
    price?: string;
    facets?: Array<string>;
}
export interface IConfigurationAlias {
    name: string;
    alias: string;
}
export interface IButtonConfiguration {
    visible?: boolean;
}
export interface IFieldConfiguration {
    visible?: boolean;
}
export interface IApplicationButtonsConfiguration {
    orderSample?: IButtonConfiguration;
    addToCart?: IButtonConfiguration;
}
export interface IApplicationFieldsConfiguration {
    price?: IFieldConfiguration;
    title?: IFieldConfiguration;
    description?: IFieldConfiguration;
}
export interface IConfigurationCatalogFilters {
    products: {
        customFields: Array<IConfigurationFilter>;
        fromDate: {
            customFieldName?: string;
        };
    };
}
export interface IConfigurationAnalyticsPluginsDetailsGDPR {
    type: string;
    cookieIds: string;
}
export interface IConfigurationAnalyticsPluginsDetails {
    trackingId: string;
    GDPR: IConfigurationAnalyticsPluginsDetailsGDPR;
}
export interface IConfigurationAnalyticsPlugins {
    name: string;
    details: IConfigurationAnalyticsPluginsDetails;
}
export interface IConfigurationAnalytics {
    plugins: Array<IConfigurationAnalyticsPlugins>;
}
export interface IPreFilterProducts {
    plugins: Array<IConfigurationAnalyticsPlugins>;
}
export interface ISceneConfigurationEntity {
    theme?: Record<string, any>;
    maxFaceSize?: number;
    maxFaceSizeMobile?: number;
    label?: string;
    sceneTitle?: string;
    sceneSubtitle?: string;
    catalogFieldsMapping?: ICatalogFieldsMapping;
    catalogFilters?: IConfigurationCatalogFilters;
    applications?: Array<IApplication>;
    fieldsAliases?: Array<IConfigurationAlias>;
    /** by creating sceneListFilters (at least only with names) at the exp level - it will determine the order in the ui */
    sceneListFilters?: Array<IConfigurationFilter>;
    analytics?: IConfigurationAnalytics;
}
export interface ISceneConfiguration {
    defaults?: ISceneConfigurationEntity;
    configurations?: Array<ISceneConfigurationEntity>;
}
export declare abstract class IVisualizer {
    /** start and load the visualizer app, will be triggered automatically on [data-role="visualizer"] elements
     * after complete will emit a "visualizerLoaded" event
     */
    abstract initAndLoad(): Promise<void>;
    /** set favorite scene */
    abstract setFavoriteScenes(favoriteScenes: IFavoriteSceneList): any;
    /** set favorite product */
    abstract setFavoriteProducts(favoriteProducts: IFavoriteProductList | IFavoriteProductShortList): any;
    /** will return the curren scene */
    abstract getCurrentScene(): IScene;
    /** will return the scene list available in this experience */
    abstract getSceneList(): Array<IScene>;
    /** will set the current scene
     * after complete will emit a "sceneLoaded" event
     *
     * @param sceneId - the sceneId to lunch
     */
    abstract setScene(sceneId: string): Promise<void>;
    /** will return products list according to the current application and filters */
    abstract getProductList(): Array<IProduct>;
    /** will return applications available on this experience */
    abstract getApplicationsList(): Array<IApplication>;
    /** will return the current applications */
    abstract getCurrentApplication(): IApplication;
    /** will set the current applications
     * @param application - the application to set
     */
    abstract setCurrentApplication(application: IApplication): Promise<IApplication>;
    /** will return the available filters */
    abstract getFilters(): Array<IConfigurationFilter>;
    /** will return the current filters */
    abstract getCurrentFilters(): Array<IConfigurationFilter>;
    /** will set the current filters
     * @param filters - the filters to set
     */
    abstract setFilter(filters: Array<IConfigurationFilter>): Array<IConfigurationFilter>;
    /** will return the available scene filters */
    abstract getSceneFilters(): Array<IConfigurationFilter>;
    /** will return the current scene filters */
    abstract getSceneCurrentFilters(): Array<IConfigurationFilter>;
    /** will set the current scene filters
     * @param filters - the scene filters to set
     */
    abstract setSceneFilter(filters: Array<IConfigurationFilter>): void;
    /** will set a product on a specific application
     * will emit a "productChanged" event after complete
     */
    abstract displayProduct(productSku: string, application: IApplication): Promise<void>;
    /** will display a saved scene
     * will emit a "sceneDisplayed" event after complete
     */
    abstract displaySceneFromFavorites(setId: string): Promise<void>;
    /** will return the product displayed on an application in the current scene */
    abstract getDisplayedProduct(application: IApplication): IProduct;
    /** will return all displayed products in the current scene*/
    abstract getDisplayedProducts(): Array<IProduct>;
    /** will add a product to favorites
     * will emit a "productAddedToFavorites" event
     */
    abstract addProductToFavorites(productSku: string, application: string): IFavoriteProductList;
    /** will remove a product from favorites
     * will emit a "productRemovedFromFavorites" event
     */
    abstract removeProductFromFavorites(productSku: string, application: string): IFavoriteProductList;
    /** will return the favorite products */
    abstract getFavoriteProducts(): IFavoriteProductList;
    /** will add a scene to favorites
     * will emit a "sceneAddedToFavorites" event
     */
    abstract addFavoriteScene(): Promise<IFavoriteSceneList>;
    /** will remove a scene from favorites
     * will emit a "sceneRemovedFromFavorites" event
     */
    abstract removeFavoriteScene(setId: string): IFavoriteSceneList;
    /** will return the favorite set list */
    abstract getFavoriteScenes(): IFavoriteSceneList;
    /** will emit a "productAddedToCart" event */
    abstract addProductToCart(product: IProduct): void;
    /** will emit a "orderSample" event */
    abstract orderSample(product: IProduct): void;
}
/**@ignore */
export declare class VisualizerElement extends Element {
    Visualizer: Visualizer;
}
export declare type ICameraEventType = 'zoom' | 'move';
/**
 * events when using addEventListener on the visualizer element
 * for example:
 * ```typescript
 * const handleOnSceneLoaded = ({ scene }) => {
 * };
 * visualizerApp.on('sceneLoaded', handleOnSceneLoaded);
 * ```
 */
export declare namespace IEventsTypes {
    /**@event */
    type OnCamera = (eventData: {
        eventType: ICameraEventType;
    }) => void;
    /**@event */
    type OnContainerInjected = (eventData: {
        visualizer: Visualizer;
    }) => void;
    /**@event */
    type OnVisualizerLoaded = (eventData: {
        visualizer: Visualizer;
    }) => void;
    /**@event */
    type OnRendered = (eventData: {
        hotspots?: {
            application: string;
            title: string;
            position: {
                x: number;
                y: number;
            };
        }[];
    }) => void;
    /**@event */
    type onHoverHotspot = (eventData: {
        hotspot: {
            application: string;
            title: string;
            isHover: boolean;
        };
    }) => void;
    /**@event */
    type OnSceneLoaded = (eventData: {
        scene: IScene;
    }) => void;
    type OnSceneLoading = (eventData: {
        scene: IScene;
        sceneConfiguration: ISceneConfigurationEntity;
    }) => void;
    /**@event */
    type OnProductChanged = (eventData: {
        product: ProductSchema.IProduct;
    }) => void;
    /**@event */
    type OnUserChangedProduct = (eventData: {
        product: ProductSchema.IProduct;
    }) => void;
    /**@event */
    type onFavoritesSceneDisplayed = (eventData: {
        scene: IFavoriteScene;
    }) => void;
    /**@event */
    type onApplicationHotspotClicked = (eventData: {
        application: IApplication;
    }) => void;
    /**@event */
    type onProductAddedToFavorites = (eventData: {
        favorites: IFavoriteProductList;
        product?: IProduct;
    }) => void;
    /**@event */
    type onSceneAddedToFavorites = (eventData: {
        favoriteScenes: IFavoriteSceneList;
        scene?: IFavoriteScene;
    }) => void;
    /**@event */
    type onProductRemovedFromFavorites = (eventData: {
        favorites: IFavoriteProductList;
        product: IProduct;
    }) => void;
    /**@event */
    type onSceneRemovedFromFavorites = (eventData: {
        favoriteScenes: IFavoriteSceneList;
        scene: IFavoriteScene;
    }) => void;
    /**@event */
    type onProductAddedToCart = (eventData: {
        product: IProduct;
    }) => void;
    /**@event */
    type onOrderSample = (eventData: {
        product: IProduct;
    }) => void;
    /**@event */
    type onAsyncOperationStarted = (eventData: {
        processId: string;
    }) => void;
    /**@event */
    type onAsyncOperationEnded = (eventData: {
        processId: string;
    }) => void;
    /**@event */
    type onSceneTouched = (eventData: {
        scene: IScene;
    }) => void;
    /**@event */
    type OnSceneConfigurationLabelChanged = () => void;
    /**@event */
    type onSummaryClicked = () => void;
    /**@event */
    type onFullscreenClicked = () => void;
    /**@event */
    type onCloseFullscreenClicked = () => void;
    /**@event */
    type onFavoritesPanelOpened = () => void;
    /**@event */
    type onFavoritesPanelClosed = () => void;
    /**@event */
    type onFavoriteSceneClicked = () => void;
    /**@event */
    type onScenesPanelOpened = () => void;
    /**@event */
    type onScenesPanelClosed = () => void;
    /**@event */
    type onApplicationsStripButtonClicked = () => void;
    /**@event */
    type onApplicationsStripOpened = () => void;
}
/**
 * events when using on/off on the visualizer instance
 * for example:
 * ```typescript
 * const onVisualizerLoaded = ({ detail }) => {
 *  const visualizerApp: Visualizer = detail.visualizer;
 *  const applications = visualizerApp.GetApplicationsList();
 *  console.log(applications);
 * };
 * const containerElement = document.querySelector('.visualizer');
 * containerElement.addEventListener('visualizerLoaded', onVisualizerLoaded);
 * ```
 */
export declare namespace IEventsTypesListeners {
    /**@event */
    type OnCamera = (event: CustomEvent & {
        detail: {
            eventType: ICameraEventType;
        };
    }) => void;
    /**@event */
    type OnContainerInjected = (event: CustomEvent & {
        detail: {
            visualizer: Visualizer;
        };
    }) => void;
    /**@event */
    type OnVisualizerLoaded = (event: CustomEvent & {
        detail: {
            visualizer: Visualizer;
        };
    }) => void;
    /**@event */
    type OnRendered = (event: CustomEvent & {
        detail: {
            hotspots?: {
                title: string;
                application: string;
                position: {
                    x: number;
                    y: number;
                };
            }[];
        };
    }) => void;
    /**@event */
    type onHoverHotspot = (event: CustomEvent & {
        detail: {
            hotspot: {
                application: string;
                title: string;
                isHover: boolean;
            };
        };
    }) => void;
    /**@event */
    type OnSceneLoaded = (event: CustomEvent & {
        detail: {
            scene: IScene;
            sceneConfiguration: ISceneConfigurationEntity;
        };
    }) => void;
    type OnSceneLoading = (event: CustomEvent & {
        detail: {
            scene: IScene;
            sceneConfiguration: ISceneConfigurationEntity;
        };
    }) => void;
    /**@event */
    type OnUserChangedProduct = (event: CustomEvent & {
        detail: {
            product: ProductSchema.IProduct;
        };
    }) => void;
    /**@event */
    type OnProductChanged = (event: CustomEvent & {
        detail: {
            product: ProductSchema.IProduct;
        };
    }) => void;
    /**@event */
    type onFavoritesSceneDisplayed = (event: CustomEvent & {
        detail: {
            scene: IFavoriteScene;
        };
    }) => void;
    /**@event */
    type onApplicationHotspotClicked = (event: CustomEvent & {
        detail: {
            application: IApplication;
        };
    }) => void;
    /**@event */
    type onProductAddedToFavorites = (event: CustomEvent & {
        detail: {
            favorites: IFavoriteProductList;
            product?: IProduct;
        };
    }) => void;
    /**@event */
    type onSceneAddedToFavorites = (event: CustomEvent & {
        detail: {
            favoriteScenes: IFavoriteSceneList;
            scene?: IFavoriteScene;
        };
    }) => void;
    /**@event */
    type onProductRemovedFromFavorites = (event: CustomEvent & {
        detail: {
            favorites: IFavoriteProductList;
            product: IProduct;
        };
    }) => void;
    /**@event */
    type onSceneRemovedFromFavorites = (event: CustomEvent & {
        detail: {
            favoriteScenes: IFavoriteSceneList;
            scene: IFavoriteScene;
        };
    }) => void;
    /**@event */
    type onProductAddedToCart = (event: CustomEvent & {
        detail: {
            product: IProduct;
        };
    }) => void;
    /**@event */
    type onOrderSample = (event: CustomEvent & {
        detail: {
            product: IProduct;
        };
    }) => void;
    /**@event */
    type onAsyncOperationStarted = (event: CustomEvent & {
        detail: {
            processId: string;
        };
    }) => void;
    /**@event */
    type onAsyncOperationEnded = (event: CustomEvent & {
        detail: {
            processId: string;
        };
    }) => void;
    /**@event */
    type onSceneTouched = (event: CustomEvent & {
        detail: {
            scene: IScene;
        };
    }) => void;
    /**@event */
    type OnSceneConfigurationLabelChanged = () => void;
    /**@event */
    type onSummaryClicked = () => void;
    /**@event */
    type onFullscreenClicked = () => void;
    /**@event */
    type onCloseFullscreenClicked = () => void;
    /**@event */
    type onFavoritesPanelOpened = () => void;
    /**@event */
    type onFavoritesPanelClosed = () => void;
    /**@event */
    type onFavoriteSceneClicked = () => void;
    /**@event */
    type onScenesPanelOpened = () => void;
    /**@event */
    type onScenesPanelClosed = () => void;
    /**@event */
    type onApplicationsStripButtonClicked = () => void;
    /**@event */
    type onApplicationsStripOpened = () => void;
}
export {};
