import { CollectionSchema, ProductSchema } from '@byondrnd/showroom-schemas';
import { IApplication, IConfigurationFilter, IFavorite, IFavoriteProductShortList, IProduct } from '../EventSystem/EventTypes';
import { Visualizer } from '../..';
import ApolloClient from 'apollo-client';
import { NormalizedCacheObject } from 'apollo-cache-inmemory';
export interface CatalogInfo {
    organization: string;
    catalog: string;
}
export declare class CatalogManager {
    catalog?: CollectionSchema.ICatalog;
    collections?: Array<CollectionSchema.ICollection>;
    assetsCollection?: CollectionSchema.ICollection;
    visualizer: Visualizer;
    catalogInfo?: CatalogInfo;
    selectionState: Map<string, {
        application?: IApplication;
        filters?: {
            [application: string]: ({
                name?: string;
                customFieldName?: string;
                operator?: "not";
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        };
    }>;
    sceneFilters?: Record<string, Record<string, IConfigurationFilter[] | undefined> | undefined>;
    private products?;
    productsList: string[];
    showroomClient?: ApolloClient<NormalizedCacheObject>;
    constructor(visualizer: Visualizer);
    init(sceneId: string): Promise<any>;
    setProductsList(skus: string[]): void;
    getProducts(): ProductSchema.IProduct[];
    getProduct(productSku: string, application: string): ProductSchema.IProduct;
    getAllFormatedProducts(): ({
        sku?: string;
        name?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: ({
            name?: string;
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        sku: string;
        title: string;
        image: string;
        application: string;
    })[];
    getProductList(sceneId: string): ({
        sku?: string;
        name?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: ({
            name?: string;
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        sku: string;
        title: string;
        image: string;
        application: string;
    })[];
    getProductListByApplication(application: IApplication): IProduct[];
    getProductListByProductFavorites(p: IFavoriteProductShortList): IFavorite[];
    getProductsMathchingCustomFields(products: ProductSchema.IProduct[], filters?: Array<IConfigurationFilter>): ProductSchema.IProduct[];
    getProductsFromDate(products: ProductSchema.IProduct[], customFieldName: string): ProductSchema.IProduct[];
    getFullProductDetails(productId: string): Promise<any>;
    getCatalogsApplications(): IApplication[];
    getApplication(application: string): IApplication;
    getApplicationAsset(application: string): ProductSchema.IProduct;
    getApplicationPreviewImage(application: string): string;
    getApplicationConfiguration(application: string): IApplication;
    getApplicationRenderOrder(application: string): number;
    getFilters(sceneId: string): ({
        name?: string;
        customFieldName?: string;
        operator?: "not";
        options?: any;
    } & {
        name: string;
        options: any;
    })[];
    loadCatalogs(): Promise<CollectionSchema.ICatalog>;
    loadCatalogCollections(): Promise<CollectionSchema.ICollection[]>;
    loadCatalogsCollections(): Promise<void>;
    private updateFilters;
}
