import { ProductSchema } from '@byondrnd/showroom-schemas';
import { Visualizer } from '../../../Visualizer';
import { LayerDisplay } from './LayerDisplay';
import { IFavorite, IFavoriteScene, IApplication, IProduct } from '../../../EventSystem/EventTypes';
export declare class ProductsManager {
    visualizer: Visualizer;
    displayedProductsMap: Map<string, LayerDisplay>;
    favoriteProducts: Array<IFavorite>;
    favoriteSets: Array<IFavoriteScene>;
    private userDisplayedProducts;
    cart: string[];
    constructor(visualizer: Visualizer);
    setFavoriteSets(input: any): any;
    setFavoriteProducts(input: any): any;
    getUserDisplayedProducts(): Record<string, string>;
    addUserDisplayedProduct(productSku: string, application: string): Promise<void>;
    displayProduct(productSku: string, application: string): Promise<void>;
    unDisplayAll(): void;
    unDisplayProduct(product: ProductSchema.IProduct): void;
    addProductToCart(sku: string): void;
    removeProductFromCart(sku: string): void;
    getFavoriteProducts(): Array<IFavorite>;
    addProductToFavorites(productSku: string, application: string): {
        sku?: string;
        name?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: ({
            name?: string;
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        sku: string;
        title: string;
        image: string;
        application: string;
    };
    removeProductFromFavorites(productSku: string, application: string): {
        sku?: string;
        name?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: ({
            name?: string;
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        sku: string;
        title: string;
        image: string;
        application: string;
    };
    getFavoriteSets(): IFavoriteScene[];
    addFavoriteScene(sceneId: string): Promise<{
        id?: string;
        image?: string;
        favorites?: ({
            product?: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        } & {
            product: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        })[];
        scene?: {
            experienceId?: string;
            sceneId?: string;
            title?: string;
            subtitle?: string;
            image?: string;
            filters?: ({
                name?: string;
                customFieldName?: string;
                operator?: "not";
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            image: string;
            experienceId: string;
            sceneId: string;
        };
    } & {
        image: string;
        id: string;
        favorites: ({
            product?: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        } & {
            product: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        })[];
        scene: {
            experienceId?: string;
            sceneId?: string;
            title?: string;
            subtitle?: string;
            image?: string;
            filters?: ({
                name?: string;
                customFieldName?: string;
                operator?: "not";
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            image: string;
            experienceId: string;
            sceneId: string;
        };
    }>;
    removeFavoriteScene(setId: string): {
        id?: string;
        image?: string;
        favorites?: ({
            product?: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        } & {
            product: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        })[];
        scene?: {
            experienceId?: string;
            sceneId?: string;
            title?: string;
            subtitle?: string;
            image?: string;
            filters?: ({
                name?: string;
                customFieldName?: string;
                operator?: "not";
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            image: string;
            experienceId: string;
            sceneId: string;
        };
    } & {
        image: string;
        id: string;
        favorites: ({
            product?: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        } & {
            product: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        })[];
        scene: {
            experienceId?: string;
            sceneId?: string;
            title?: string;
            subtitle?: string;
            image?: string;
            filters?: ({
                name?: string;
                customFieldName?: string;
                operator?: "not";
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            image: string;
            experienceId: string;
            sceneId: string;
        };
    };
    getDisplayedProduct(application: IApplication): IProduct;
    getDisplayedFormatedProduct(): Array<IProduct>;
    getApplicationLayerDisplay(application: string, renderOrder: number): Promise<LayerDisplay>;
    getDisplayedProducts(): Array<ProductSchema.IProduct>;
}
