import { TypedEmitter } from 'tiny-typed-emitter';
import { Utils, AppManager } from '@byondrnd/byond-web-lib';
import { CatalogManager } from './Managers/CatalogManager';
import { ProductsManager } from './Managers/Scene/ProductsManager/ProductsManager';
import { IEventSystem, EventSystemEventSignature, EventSystemEventDataSignature, IConfigurationFilter, IProduct, IApplication, VisualizerElement, IVisualizer } from './EventSystem/EventTypes';
import { SceneMetadataManager } from './Managers/Scene/SceneMetadataManager';
import { ImageOptimizeService } from '../utils/ImageOptimizeService';
declare type THotspotPoint = {
    application: string;
    title: string;
    obj: any;
};
export declare type TDefaultProducts = Record<string, string>;
export declare class Visualizer extends TypedEmitter<IEventSystem> implements IVisualizer {
    appManager: AppManager;
    sceneSelector: string;
    mainContainerElement: VisualizerElement;
    sceneId?: string;
    sceneConfigurationLabel?: string;
    catalogManager: CatalogManager;
    productsManager: ProductsManager;
    sceneMetadataManager: SceneMetadataManager;
    debug: boolean;
    pubs: Utils.RxUtils.Subscription[];
    initAndLoaded: boolean;
    defaultProducts?: TDefaultProducts;
    defaultProduct?: string;
    maxFaceSize: number | null;
    maxFaceSizeMobile: number | null;
    experienceId?: string;
    experienceHash?: string;
    hotspots: THotspotPoint[];
    divs: HTMLDivElement[];
    divFirstGo: boolean[];
    ImageOptimizeService: ImageOptimizeService;
    imageOptimizerUrl: string;
    defaultApplication: string;
    constructor(containerSelector: string, sceneSelector: string);
    initAndLoad(): Promise<void>;
    setScene(sceneId: string, preventDefaultProducts?: boolean, preventEvent?: boolean, defaultApplication?: string): Promise<void>;
    emitRender(): void;
    setFavoriteScenes(favoriteScenes: any): void;
    setFavoriteProducts(favoriteProducts: any): void;
    private onZoneLoaded;
    private initCatalog;
    initialProductDisplay(params?: {
        defaultProduct?: string;
        defaultProducts?: TDefaultProducts;
    }): Promise<void>;
    savedUserProductsDisplay(userSetProducts: TDefaultProducts): Promise<void>;
    setSceneConfigurationLabel({ sceneConfigurationLabel, sceneId, productsList, defaultApplication, }: {
        sceneConfigurationLabel?: string;
        sceneId?: string;
        productsList?: string[];
        defaultApplication?: string;
    }): Promise<void>;
    getCurrentSceneConfiguration(): import("./EventSystem/EventTypes").ISceneConfigurationEntity;
    private subEventsAnalytics;
    private emitEventsAnalytics;
    getCurrentCatalogFieldsMap: () => import("./EventSystem/EventTypes").ICatalogFieldsMapping;
    getCurrentApplication(): IApplication;
    setCurrentApplication(application: IApplication | string, evenIfInView?: boolean): Promise<IApplication>;
    getFilters(): ({
        name?: string;
        customFieldName?: string;
        operator?: "not";
        options?: any;
    } & {
        name: string;
        options: any;
    })[];
    getCurrentFilters(): ({
        name?: string;
        customFieldName?: string;
        operator?: "not";
        options?: any;
    } & {
        name: string;
        options: any;
    })[];
    setFilter(filters: IConfigurationFilter[]): ({
        name?: string;
        customFieldName?: string;
        operator?: "not";
        options?: any;
    } & {
        name: string;
        options: any;
    })[];
    getFilterCount(filterName: string): Map<string, number>;
    getSceneFilters(): ({
        name?: string;
        customFieldName?: string;
        operator?: "not";
        options?: any;
    } & {
        name: string;
        options: any;
    })[];
    getSceneCurrentFilters(): ({
        name?: string;
        customFieldName?: string;
        operator?: "not";
        options?: any;
    } & {
        name: string;
        options: any;
    })[];
    setSceneFilter(filters: IConfigurationFilter[]): void;
    getDisplayedProduct(application: IApplication): {
        sku?: string;
        name?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: ({
            name?: string;
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        sku: string;
        title: string;
        image: string;
        application: string;
    };
    getDisplayedProducts(): ({
        sku?: string;
        name?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: ({
            name?: string;
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        sku: string;
        title: string;
        image: string;
        application: string;
    })[];
    getProductList(): ({
        sku?: string;
        name?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: ({
            name?: string;
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        sku: string;
        title: string;
        image: string;
        application: string;
    })[];
    getApplicationsList(): IApplication[];
    addProductToFavorites(productSku: string, application: string): ({
        product?: {
            sku?: string;
            name?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: ({
                name?: string;
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            sku: string;
            title: string;
            image: string;
            application: string;
        };
    } & {
        product: {
            sku?: string;
            name?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: ({
                name?: string;
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            sku: string;
            title: string;
            image: string;
            application: string;
        };
    })[];
    removeProductFromFavorites(productSku: string, application: string): ({
        product?: {
            sku?: string;
            name?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: ({
                name?: string;
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            sku: string;
            title: string;
            image: string;
            application: string;
        };
    } & {
        product: {
            sku?: string;
            name?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: ({
                name?: string;
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            sku: string;
            title: string;
            image: string;
            application: string;
        };
    })[];
    getFavoriteProducts(): ({
        product?: {
            sku?: string;
            name?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: ({
                name?: string;
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            sku: string;
            title: string;
            image: string;
            application: string;
        };
    } & {
        product: {
            sku?: string;
            name?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: ({
                name?: string;
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            sku: string;
            title: string;
            image: string;
            application: string;
        };
    })[];
    addFavoriteScene(): Promise<({
        id?: string;
        image?: string;
        favorites?: ({
            product?: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        } & {
            product: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        })[];
        scene?: {
            experienceId?: string;
            sceneId?: string;
            title?: string;
            subtitle?: string;
            image?: string;
            filters?: ({
                name?: string;
                customFieldName?: string;
                operator?: "not";
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            image: string;
            experienceId: string;
            sceneId: string;
        };
    } & {
        image: string;
        id: string;
        favorites: ({
            product?: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        } & {
            product: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        })[];
        scene: {
            experienceId?: string;
            sceneId?: string;
            title?: string;
            subtitle?: string;
            image?: string;
            filters?: ({
                name?: string;
                customFieldName?: string;
                operator?: "not";
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            image: string;
            experienceId: string;
            sceneId: string;
        };
    })[]>;
    removeFavoriteScene(setId: string): ({
        id?: string;
        image?: string;
        favorites?: ({
            product?: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        } & {
            product: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        })[];
        scene?: {
            experienceId?: string;
            sceneId?: string;
            title?: string;
            subtitle?: string;
            image?: string;
            filters?: ({
                name?: string;
                customFieldName?: string;
                operator?: "not";
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            image: string;
            experienceId: string;
            sceneId: string;
        };
    } & {
        image: string;
        id: string;
        favorites: ({
            product?: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        } & {
            product: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        })[];
        scene: {
            experienceId?: string;
            sceneId?: string;
            title?: string;
            subtitle?: string;
            image?: string;
            filters?: ({
                name?: string;
                customFieldName?: string;
                operator?: "not";
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            image: string;
            experienceId: string;
            sceneId: string;
        };
    })[];
    getFavoriteScenes(): ({
        id?: string;
        image?: string;
        favorites?: ({
            product?: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        } & {
            product: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        })[];
        scene?: {
            experienceId?: string;
            sceneId?: string;
            title?: string;
            subtitle?: string;
            image?: string;
            filters?: ({
                name?: string;
                customFieldName?: string;
                operator?: "not";
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            image: string;
            experienceId: string;
            sceneId: string;
        };
    } & {
        image: string;
        id: string;
        favorites: ({
            product?: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        } & {
            product: {
                sku?: string;
                name?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: ({
                    name?: string;
                    options?: any;
                } & {
                    name: string;
                    options: any;
                })[];
            } & {
                sku: string;
                title: string;
                image: string;
                application: string;
            };
        })[];
        scene: {
            experienceId?: string;
            sceneId?: string;
            title?: string;
            subtitle?: string;
            image?: string;
            filters?: ({
                name?: string;
                customFieldName?: string;
                operator?: "not";
                options?: any;
            } & {
                name: string;
                options: any;
            })[];
        } & {
            image: string;
            experienceId: string;
            sceneId: string;
        };
    })[];
    getSceneList(): ({
        experienceId?: string;
        sceneId?: string;
        title?: string;
        subtitle?: string;
        image?: string;
        filters?: ({
            name?: string;
            customFieldName?: string;
            operator?: "not";
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        image: string;
        experienceId: string;
        sceneId: string;
    })[];
    addProductToCart(product: IProduct): void;
    orderSample(product: IProduct): void;
    getCurrentSceneImage(): Promise<string>;
    getCurrentScene(): {
        experienceId?: string;
        sceneId?: string;
        title?: string;
        subtitle?: string;
        image?: string;
        filters?: ({
            name?: string;
            customFieldName?: string;
            operator?: "not";
            options?: any;
        } & {
            name: string;
            options: any;
        })[];
    } & {
        image: string;
        experienceId: string;
        sceneId: string;
    };
    displayProduct(productSku: string, application: IApplication, animateToProduct?: boolean): Promise<void>;
    displaySceneFromFavorites(id: string): Promise<void>;
    fetchMetadata(): Promise<string>;
    rotateCameraToApplication({ application, evenIfInView }: {
        application: string;
        evenIfInView?: boolean;
    }): Promise<void>;
    private initScene;
    THREEBox: any;
    isObjectVisible: any;
    private toScreenPosition;
    private unRegisterEvents;
    private registerEvents;
    private navigate;
    private loadProps;
    emit(eventName: EventSystemEventSignature, ...args: EventSystemEventDataSignature): boolean;
}
export {};
